function SeisSound_IRIS(metadata,data,phaseTime,basedir)
%-----------------------------------------
%
% Description of input parameters
%
%    1. metadata - structure that stores metadata information
%    2. data - structure that stores data
%    3. phaseTime  - structure that stores phase arrival information 
%
% You will also need the following Matlab scripts 
%
%    - linex.m
%    - epoch.m
%    - eqfiltfilt.m
%    - irisFetch.m
%    - jday.m
%    - linex.m
%    - stadis2.m
%    - taupCurve.m
%    - taup.m
%    - taupPath.m
%    - taupPierce.m
%    - taupTime.m
%    - VCO_seismogram.m
%
%  Additional information can be obtained from the 2012 SRL article by Kilb et al., titled:
%    Listen, Watch, Learn: SeisSound Video products
%
   if nargin < 1, disp('ERROR: need to define metadata'); keyboard ; end
   if nargin < 2, disp('ERROR: need to define data'); keyboard ; end
   if nargin < 3, disp('ERROR: need to define phase data'); keyboard ; end
%
%  Define base parameters and static values
%
      filt_low = metadata.filt_low;
      filt_high = metadata.filt_high;
      speed_factor = metadata.speed_factor;
      ColorBar_Upper_Limit = metadata.ColorBar_Upper_Limit;
      ColorBar_Lower_Limit = metadata.ColorBar_Lower_Limit;
      FramesPerSecond = metadata.FramesPerSecond;

      units = metadata.units;
      dtype = metadata.dtype;
      debug = metadata.debug;
      irisid = metadata.iris_id;
      net = data.network;
      sta = data.station;
      chan  = data.channel;
      starttime = metadata.str_time_beginit;
      endtime = metadata.str_time_endit;
      j1 = min(find(isstrprop(metadata.magstr,'digit')==1));
      j2 = max(find(isstrprop(metadata.magstr,'digit')==1));
      %mag  = num2str(metadata.magstr(4:6));
      mag  = num2str(metadata.magstr(j1:j2)); % assumes '.' is inbetween non-consecutive numbers
      ff_max = metadata.ff_max;
      mmmm =datestr(datenum(2000,str2num(metadata.mm),01),'mmmm');
      titleit = [mmmm,' ',metadata.dd,', ',metadata.yyyy,', ',caseconvert(metadata.region_name,'title')];
%
      headerFontSize        = 14;         % movie header font size
      labFontSize           = 12;         % axis label font size
      pSlowness             = metadata.pSlowness; % P slowness (s/degree);  a P slowness of ~ 7.2 s/deg (should be conservative out to 125 deg)
      rSlowness             = metadata.rSlowness;  % Rayleigh slowness (s/degree); orig 29.835 but use 28.5 to provides a better phase display
      %iSlowness            = metadata.iSlowness; % Infrasound slowness (s/degree)
%
%  SIO logo file location and plot location information
%
    sioLogo              = '../image/sio_logo_color.jpg'; % SIO logo 
    sioLogoRight         = 0.140;  % SIO logo position, right
    sioLogoUp            = 0.025; % SIO logo position, up
    sioLogoWidth         = 0.082; % SIO logo width
    sioLogoHeight        = 0.080;% SIO logo height
    sioLogoPosition      = [sioLogoRight,sioLogoUp,sioLogoWidth,sioLogoHeight]; % lower left,size
%
%  IRIS logo file location and plot location information
%
    irisLogo              = '../image/IRISlogo70.png'; % IRIS logo file
    scalelogo = 1.00;
    irisLogoRight         = 0.015;  % IRIS logo position, right
    irisLogoUp            = 0.015; % IRIS logo position, up
    irisLogoWidth         = scalelogo*0.1246; % IRIS logo width
    irisLogoHeight        = scalelogo*0.08;% IRIS logo height
    irisLogoPosition      = [irisLogoRight,irisLogoUp,irisLogoWidth,irisLogoHeight]; % lower left,size
%
    tempA = [irisid,'_',net,'_',sta,'_',chan,'_'];
    tempB = [metadata.yyyy,'_',metadata.mm,'_',metadata.dd,'_',...
        metadata.hh,metadata.mn,metadata.sec];
    inputdata = [tempA,tempB];

    scaleinfo = [' -vf scale=-1:',num2str(metadata.movie_height),' '];
    name_end= ['_',num2str(metadata.movie_height),'.mp4'];
%
%  Define time of the earthquake
%
   eqtime_datenum = datenum(str2num(metadata.yyyy),str2num(metadata.mm),str2num(metadata.dd),str2num(metadata.hh),str2num(metadata.mn),str2num(metadata.sec));

   if debug
      disp('~~~~~~~ SELECT PARAMETERS ~~~~~~~')
      disp(['irisid: ',num2str(irisid)]);
      disp(['net: ',net]);
      disp(['sta: ',sta]);
      disp(['chan: ',chan]);
      disp(['starttime=',num2str(starttime)]);
      disp(['endtime=',num2str(endtime)])
      disp(['titleit: ',titleit]);
      disp(['filt_low=',num2str(filt_low)]),
      disp(['filt_high=',num2str(filt_high)]),
      disp(['ff_max=',num2str(ff_max)]),
      disp(['units: ',units]),
      disp(['dtype: ',dtype]),
      disp(['speed_factor=',num2str(speed_factor)])
      disp(['ColorBar_Upper_Limit=',num2str(ColorBar_Upper_Limit)])
      disp(['ColorBar_Lower_Limit=',num2str(ColorBar_Lower_Limit)])
      disp(['FramesPerSecond=',num2str(FramesPerSecond)])
      disp('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
   end
%
%  Define directory sturcture and static parameters
%
   basedir_audio = [basedir, '/Audio'];
   audiofile=[basedir, '/Audio/',inputdata,'.wav'] ;
   audiofile_vco=[basedir, '/Audio/',inputdata,'_vco.wav'] ;
   filename=[basedir,'/',inputdata];

    scale = 1.0;
    icount=0;
    nfft = 256;
    %nfft = 128;
    if ff_max > 0
       freq_zoom = 1;
       ff_min = 0;
    else
       freq_zoom = 0;
    end

    %FramesPerSec_options = [1 2 6 10 12 15 25 30 50 60];
    FramesPerSec_options = [1 6 10 12 15 25 30 50 60]; % FPS of 2 produces a 'green' screen avoid

    Plot1_Length = 0.80;
    Plot1_Height = 0.24;
    Plot1_Xposition = 0.15;
    Plot1_Yposition = 0.65;

    Plot2_Length = 0.80;
    Plot2_Height = 0.24;
    Plot2_Xposition = 0.15;
    Plot2_Yposition = 0.40;

    Plot3_Length = 0.80;
    Plot3_Height = 0.24;
    Plot3_Xposition = 0.15;
    Plot3_Yposition = 0.15;
%
    sec2days = 1/(60*60*24);
    day2sec = 60*60*24;
%
% Create necessary folders and remove existing files if needed
%
    fileDirNameImage = [ basedir,'/Images/'];
    fileDirNameMovies = [ basedir,'/Movies/'];
    fileDirNameAudio = [ basedir,'/Audio/'];
    fileRenderName = [ basedir,'/Images_',num2str(irisid),'/img'];
    fileDirName = [ basedir,'/Images_',num2str(irisid)];
    string_mkdir = ['mkdir ',basedir];
    if ~exist(fileDirNameImage,'dir')
        system([string_mkdir '/Images']);
    end
    if ~exist(fileDirNameMovies,'dir')
        system([string_mkdir '/Movies']); 
    end
    if ~exist(fileDirNameAudio,'dir')
        system([string_mkdir '/Audio']);
    end
    if exist([basedir,'/Movies/',inputdata,'.mp4'],'file')
        if (debug)
           disp(['Deleting pre-existing movie: ',inputdata,'.mp4']);
        end
        system(['rm ',basedir,'/Movies/',inputdata,'.mp4']);
    end
    if exist([basedir,'/Movies/',inputdata,name_end],'file')
        if (debug)
           disp(['Deleting pre-existing movie: ',inputdata,name_end]);
        end
        system(['rm ',basedir,'/Movies/',inputdata,name_end]);
    end
    if exist(fileDirName,'dir')
        if (debug)
           disp(['Deleting pre-existing directory: ',fileDirName]);
        end
        pwdkeep = pwd;
        system(['rm -r ',fileDirName]);
    end
    system(['mkdir ',fileDirName]);
%
% Define key data paramters
%
     delta = 1./data.sampleRate; 
     time = [delta:delta:delta*length(data.data)];
     starttime = min(time);
     endtime = max(time);
     time_offset = (data.startTime - eqtime_datenum)*day2sec;
     if (debug)
        disp(['Debug ',num2str(time_offset),' seconds between earthquake and start of trace'])
        debug_eq = datestr(eqtime_datenum)
        debug_start = datestr(data.startTime)
        debug_end = datestr(data.endTime)
     end
%
%  Remove mean and correct for instrument response
%
     trace = data.data - median(data.data);
     if data.sensitivity~=0
         trace  = trace./data.sensitivity;
     else
         disp('WARNING: data.sensitivity set to zero, no instrument correction incorporated')
     end
     trace = double(trace);
     Nf = 1/(2*delta);
%
%  Check requested frequency band is not above the nyquest
%
     if filt_high>=Nf
        filt_high = 0.999*Nf;
        if (debug)
           disp('Frequency requested is above Nyquest, reassinging')
        end
     end
%
%  Check for spikes in the data; this doesn't work correctly
%
%    if (max(abs(trace))/std(trace)) > 6
%       disp(['CAUTION: -- there appears to be a noise spike in data: ',inputdata])
%       %disp(num2str(max(abs(trace)))) 
%       %disp(num2str(std(trace)))
%       %disp(num2str(max(abs(trace))/std(trace)))
%    end
%
%  Expand title with additional parameters if available
%
     titleit2 = [];
     if mag>0
        %titleit = [titleit,', Magnitude ',num2str(mag)];
        titleit = [titleit,', M=',num2str(mag)];
     end
     if metadata.depth>0
        %titleit = [titleit,', Depth ',num2str(data.depth,4),' km']; % do not use this, it gets the station depth, not eq depth!
        titleit = [titleit,', Depth ',num2str(metadata.depth,4),' km'];
     end
     titleit = [titleit,'   ']; % add space at end to avoid cut off, only a problem on Kilb local machine, OK at IRIS
     if length(data.station)>0
        if length(metadata.site)>27
           icomma = find(metadata.site==',');
           metadata.site = metadata.site(1:icomma(1)-1);
           %if metadata.site == 'Adam Dziewonski Observatory (Oak Ridge), Massachusetts, USA'
           if length(metadata.site)==39
              if metadata.site == 'Adam Dziewonski Observatory (Oak Ridge)'
                 metadata.site = 'Oak Ridge, Massachusetts';
              end
           end
           if (debug)
              disp('WARNING: metadata.site name was too long, shortened')
           end
        end
        titleit2 = [titleit2,metadata.site,', Station ',data.station];
     end
     %if and(length(data.latitude)>0,length(data.longitude)>0)
     %   titleit2 = [titleit2,'Station ',data.station,', Network ',data.network,...
     %     ', Lat ',num2str(data.latitude,4),', Lon ',num2str(data.longitude,4)];
     %end
     if metadata.distgc>0
        %titleit2 = [titleit2,', \Delta=',num2str(metadata.distgc,3),'\circ']
        %titleit2 = [titleit2,', Distance ',num2str(metadata.distgc,3),'\circ/',num2str(distkm,'%5.0f'),' km']
        distkm = deg2km(metadata.distgc);
        titleit2 = [titleit2,', Distance ',num2str(metadata.distgc,3),'\circ/',num2str(distkm,'%5.0f'),' km'];
     end
% 
% Degree symbol works differently on dpstage than Kilb's local machine, plan accordingly
%
     if metadata.azimuth>0
        titleit2 = [titleit2,', Azimuth ',strtrim(num2str(metadata.azimuth,3)),'\circ'];
     end
     titleit2 = [' ',titleit2,' ']; % Add white space to avoid text from being truncated on Kilb local machine
%
     %ylabelfull = [dtype,' Channel ',chan,' ',units];
     %ylabelfull = [' ',dtype,' Channel ',chan,' ',units,' ']; % add leading/ending spaces to avoid y-label from being cut off
     ylabelfull = [chan,' Channel, ',dtype,' ',units]; 
%
%  Filter the data as requested:
%      input: data, time
%      output: databp, timebp
%  Also, to see more detail in the spectrogram we apply a 0.5 hz high-pass filter.
%  This high-pass-filter is used for plotting the spectrogram & creating the audio file
%      input: data, time
%      output: datahp1, timehp1
%
     if (debug)
        if isinf(filt_low)
           disp(['Filtering data: High Pass at ',num2str(filt_high),' Hz']);
        elseif isinf(filt_high)
           disp(['Filtering data: Low Pass at ',num2str(filt_low),' Hz']);
        else
           disp(['Filtering data: ',num2str(filt_low),' to ',num2str(filt_high),' Hz']);
        end
     end
     databp = eqfiltfilt(trace,filt_low,filt_high,delta,4);
     timebp = time;

     hp1exists = 1;
     %datahp1=eqfiltfilt(trace,0.5,-inf,delta,4); % high pass at 0.5 Hz
     %datahp1=eqfiltfilt(trace,0.04,-inf,delta,4); % Andy's suggestion, revisit
     %datahp1=eqfiltfilt(trace,0.4,-inf,delta,4); % Andy's suggestion, revisit
     datahp1=eqfiltfilt(trace,metadata.filt_low_spectra,metadata.filt_high_spectra,delta,4); 
     timehp1 = time;
%
% Generate Audio File
%
%   It is important to normalize the data to be <1 and >-1:
%        data_wave_norm = data_wav/max(abs(data_wav)*1.0001);
%   before calling the MATLAB wavwrite program to avoid warnings 
%   about data clipping of the form ‘Warning: data clipped during
%   write to file’. 
% 
% An alternative way to accomplish this is to use this command
%    sac2wav(filename, audiofile, speed_factor, scale, starttime, endtime);
%
    data_sound = eqfiltfilt(trace,metadata.filt_low_sound,metadata.filt_high_sound,delta,4);
    nsamp = 1/delta;
    FS = floor(nsamp*speed_factor);
    NBITS = 16;
    AudioData = data_sound./(max(abs(data_sound))*1.0001);
    if (metadata.iflag_stereo==1)
       Audio_data_stereo(:,1) = AudioData; % side1
       Audio_data_stereo(:,2) = AudioData; % side2
       wavwrite(Audio_data_stereo,FS,NBITS,audiofile) % this makes a stereo file
    else
       wavwrite(data_sound./(max(abs(data_sound))*1.0001),FS,NBITS,audiofile) % this makes a mono file
    end
%
    [wave, fs] =wavread(audiofile);
    [M,N]=size(wave);
    soundLength = M/fs;
%
%  If requested, create an audio file with VCO
%
    if metadata.iflag_vco
       VCO_seismogram(metadata,time, data, audiofile_vco)
    end
%
%  To be in sync with the sound file, define the number of frames to be generated 
%
    FramesWant = 100;
    %FramesWant = 2;
    %disp('>>>>> while debuging set FramesWant to 2 !!!!!!!!!!!!!!!')
    if FramesPerSecond < 0
       for k=1:length( FramesPerSec_options )
           ntest(k) = soundLength*FramesPerSec_options(k);
       end
       [a,b] = min(abs(ntest-FramesWant));
       FramesPerSecond=FramesPerSec_options(b);
    end
    if (debug)
       disp(['FramesPerSecond = ',num2str(FramesPerSecond)]);
    end
    FramesTotal = soundLength*FramesPerSecond;
   
    if FramesTotal>1000
       disp('CAUTION: The total number of frames requested is > 1000')
    end

    if mod(FramesTotal,1)>0
       FramesTotal_orig = FramesTotal;
       FramesTotal = floor(FramesTotal);
       if (debug)
          disp(['CAUTION: Non integer number of frames requested'])
          disp(['         Reducing from ',num2str(FramesTotal_orig),' frames to ',num2str(FramesTotal),'.']);
       end
    end

    [r,c]=find(time<starttime);
    [RowLength1,ColumnLength1]=size(r);

    RowLength1 = max(1,RowLength1);

    [r,c]=find(time'<=endtime);
    [RowLength2, ColumnLength2] = size(r);
    Timeinterval=RowLength2-RowLength1+1;
    interval = Timeinterval/(FramesTotal);
    interval=floor(interval);
%
% Generate the spectrogram
%
    window = nfft;
    noverlap = round(nfft*0.75);
    sample_rate = round(1/delta);
    if hp1exists == 1,
        [B,F,T] = specgram(datahp1(RowLength1:RowLength2),nfft,sample_rate,window,noverlap);
        %[B_256,F_256,T_256] = specgram(datahp1(RowLength1:RowLength2),256,sample_rate,256,round(256*0.75));
        %[B_128,F_128,T_128] = specgram(datahp1(RowLength1:RowLength2),128,sample_rate,128,round(128*0.75));
        %[B_orig,F_orig,T_orig] = specgram(trace(RowLength1:RowLength2),nfft,sample_rate,window,noverlap);
    else
        [B,F,T] = specgram(trace(RowLength1:RowLength2),nfft,sample_rate,window,noverlap);
    end;
    Bmax = max(max(B));
%
% Create axis labels
%    -- use strrep to force underscore characters to be visible
%
    %Plot1_Label2 = strrep(inputdata,'_','\_');

    if (filt_high <0),
          Plot2_Label2 = ['High-Pass ' num2str(filt_low) ' Hz'];
    elseif (filt_low < 0 ),
          Plot2_Label2 = ['Low-Pass ' num2str(filt_high) ' Hz'];
    elseif (filt_low > 0 & filt_high > 0 & filt_low<filt_high),
          Plot2_Label2 = ['Band-Pass ' num2str(filt_low) '-' num2str(filt_high) ' Hz'];
    else
          Plot2_Label2 = ['Band-Stop ' num2str(filt_low) '-' num2str(filt_high) ' Hz'];
    end;

    Plot3_Label2 = 'Spectrogram';

    if (freq_zoom), 
       if ff_max<=max(F)
          if (debug)
             disp(['Restricting maximum frequency in spectrogram to ',...
                 num2str(ff_max),' Hz']);
          end
          Plot3_yaxis_upper_limit = ff_max;
       else
          disp(['CAUTION: Ignoring requested maximum frequency in spectrogram because requested ',...
              num2str(ff_max),' Hz is larger than the maximum frequency of ',...
              num2str(max(F)),' Hz']);
          Plot3_yaxis_upper_limit = max(F);
          ff_max = max(F);
       end
    else,
       Plot3_yaxis_upper_limit = max(F);
       ff_max = max(F);
    end;
%
% Avoid issues with roll-off effect of the instrument response 
% Important Note: need to revisit w/poles and zeros and correctly update, this is a quick fix for IRIS poster 2012
%
      %Plot3_yaxis_upper_limit = 0.45*max(F);
      if max(F)<11
         Plot3_yaxis_upper_limit = 0.8*max(F);
      else
         Plot3_yaxis_upper_limit = 0.9*max(F);
      end
%

    max_data = max(abs(trace(time>=starttime & time<=endtime)));
    max_databp = max(abs(databp(time>=starttime & time<=endtime)));
    Spectrogram_yaxis = ' Frequency (Hz) '; % Add spaces to avoid y-axis from being cut off
    Xaxis = ['Time since earthquake (hh:mm:ss), ' num2str(speed_factor) ' times faster than true speed']; % add spaces
    if (metadata.iflag_vco)
        Xaxis = [{Xaxis,'audio, includes modulated signal'}];
    end
%
%  Create Images
%
   close all
   figure(1);
   ibreakme = 0;
   for frame=RowLength1:interval:RowLength2;
       if ibreakme 
          break; % Need only make one sample image, not full movie
       end
       if metadata.iflag_movie==0
          if debug    
             disp('debug: no need to make full movie, just make sample image')
          end
          frame =  floor(0.35*FramesTotal);
          icount = frame -1; 
          ibreakme = 1;
       end

        clf;
        icount=icount+1;

        subplot 311 % Plot seismogram
	plot(time_offset + time(RowLength1:RowLength2),trace(RowLength1:RowLength2), 'Color', [.8 .8 .8]);
	hold on
	plot(time_offset + time(RowLength1:frame),trace(RowLength1:frame),'Color', [.2 .2 .2]);
        axis tight
	h = linex(time_offset + time(frame));
        set(h,'Color','magenta','LineWidth',3);
        hold off
        xlim(time_offset + [starttime, endtime]);
        set(gca,'Position',[Plot1_Xposition Plot1_Yposition Plot1_Length Plot1_Height])
        set(gca,'XTickLabel',[])

        h=ylabel(ylabelfull);
        set(h,'FontName','Arial','FontWeight','demi','FontSize',labFontSize);
        xx3 = time_offset + starttime-(endtime-starttime)*0.10;
        set(h,'Position',[xx3   max_data*(-1.0)    1.0001]);
        xposition =time_offset + (endtime-(endtime-starttime)*0.05);
        yy = get(gca,'Ylim');
        yposition1 = 0.9*yy(2);
        ht=title({['\fontsize{13}',titleit],['\fontsize{13}',titleit2]},'FontName','Arial','FontWeight','demi');
        now_datenum = eqtime_datenum + time_offset*sec2days + time(frame)*sec2days;
        tlab = [datestr(now_datenum),' UTC'];
        h=text(xposition, yposition1, tlab);
        set(h,'HorizontalAlignment','right','FontName','Arial','FontWeight','demi','Color','k');
        h=text(xposition,yposition1*0.8,'Unfiltered');
        set(h,'HorizontalAlignment','right','FontName','Arial','FontWeight','demi','Color','k');
%
%  Add phase arrivals if requested by user
%
        if (metadata.iflag_phases)
           sub_phases
        end

        box on
        set(gca,'Xtick',[])
        %set(gca, 'YTickLabel', num2str(get(gca, 'YTick').')); % this one doesnot work Avoid exponent overprinting 
        % nope, need the .' set(gca, 'YTickLabel', num2str(get(gca, 'YTick'),'%12.2f')); % Avoid exponent overprinting 
        yset = get(gca,'YTick');
        [junk1,junk2]=min(abs(yset));
        if yset(junk2)<1e-6
           yset(junk2) = 0; % Avoid e-17 label in the y-axis, force to zero
        end
        set(gca,'YTick',yset); % attempt to fix mis labeled y-axis ticks for 1822213_BK_PKD_BHZ_2004_11_11_212642
        set(gca, 'YTickLabel', num2str(get(gca, 'YTick').','%12.6G')); % Avoid exponent overprinting 
%
        subplot 312 % Filtered Seismogram
        plot(time_offset + timebp(RowLength1:RowLength2),databp(RowLength1:RowLength2), 'Color', [.8 .8 .8]);
        hold on
        plot(time_offset + timebp(RowLength1:frame),databp(RowLength1:frame),'Color', [.2 .2 .2]);
        h = linex(time_offset + time(frame));
        set(h,'Color','magenta','LineWidth',3);
        hold off
        xlim(time_offset + [starttime,endtime]);
%       ylabel('Amplitude (cm/s/s)');
        ylim([-1.0 1.0].*max_databp);
        xposition =(time_offset + endtime-(endtime-starttime)*0.05);
        yposition1 = 0.9*(max_databp);
        h=text(xposition, yposition1, Plot2_Label2);
        set(h,'HorizontalAlignment','right');
        set(gca,'Position',[Plot2_Xposition Plot2_Yposition Plot2_Length Plot2_Height],'XTickLabel',[])
%
%  Add phase arrivals if requested by user
%
        if (metadata.iflag_phases)
           sub_phases
        end
        box on
        set(gca,'Xtick',[])
        set(gca, 'YTickLabel', num2str(get(gca, 'YTick').')); % Avoid exponent overprinting 
        yticknow = get(gca,'Ytick');
        yy = get(gca,'Ylim');
        %set(gca,'Ylim',1.3*yy)
        set(gca,'Ytick',yticknow)
        set(gca, 'YTickLabel', num2str(get(gca, 'YTick').','%12.6G')); % Avoid exponent overprinting 

        subplot 313 % Spectrogram
        if hp1exists ==1,
            imagesc(time_offset + timehp1(RowLength1:RowLength2),F,log10(abs(B./Bmax)).*(10))
            %imagesc(time_offset + timehp1(RowLength1:RowLength2),F,log10(abs(B./Bmax)).*(20))
        else
            imagesc(time_offset + time(RowLength1:RowLength2),F,log10(abs(B./Bmax)).*(10));
            %imagesc(time_offset + time(RowLength1:RowLength2),F,log10(abs(B./Bmax)).*(20));
        end;
        caxis([ColorBar_Lower_Limit, ColorBar_Upper_Limit]);
        axis xy,
        colormap(jet);
        hc = colorbar('Location','SouthOutside');
        pp = get(hc,'Position');
        pnew = pp(1) + 0.2*pp(3);
        set(hc,'Position',[pnew 0.3*pp(2) 0.70*pp(3) pp(4)]);
        xt = get(hc,'XTick');
        set(hc,'Xtick',[min(xt) 0.5*(min(xt)-max(xt)) max(xt)]); % Might want to check sign of max and min and make this more robust ....
        %labc1 = num2str(min(xt));
        labc1 = 'low';
        labc2 = 'Amplitude';
        %labc2 = 'log10 of normalized Amplitude multiplied by 10';
        %labc3 = num2str(max(xt));
        labc3 = 'high';
        cmpr12 = (length(labc2)-length(labc1));
        cmpr23 = (length(labc2)-length(labc3));
        spaceme = ' ';

        if cmpr12~=0
           for kk = 1:cmpr12
              labc1=[labc1,spaceme];
           end
        end
        if cmpr23~=0
           for kk = 1:cmpr23
              labc3=[spaceme,labc3];
           end
        end
        set(hc,'XTickLabel',[labc1; labc2; labc3])
	hold on
        h=linex(time_offset + time(frame));
        set(h,'Color','magenta','LineWidth',3);
        hold off;
        xlim(time_offset + [starttime,endtime]);
        ylim([0, Plot3_yaxis_upper_limit])
        set(gca,'Position',[Plot3_Xposition Plot3_Yposition Plot3_Length Plot3_Height]);
        a=ylabel(Spectrogram_yaxis);
        set(a, 'Position', [time_offset + (starttime-(endtime-starttime)*0.10), (Plot3_yaxis_upper_limit*.5), 1], 'FontSize', labFontSize);
        set(a,'FontName','Arial','FontWeight','demi');
        hx = xlabel(Xaxis);
        set(hx,'FontName','Arial','FontSize',labFontSize,'FontWeight','demi')
        xposition =time_offset + (endtime-(endtime-starttime)*0.05);
        yposition1 = (Plot3_yaxis_upper_limit-(Plot3_yaxis_upper_limit/5.5));
        h=text(xposition, yposition1, Plot3_Label2);
        set(h,'HorizontalAlignment','right');
%
%  >>>> BELOW STOLEN FROM GMV <<<<<
%
% relabel the time ticks
%
        xTick                 = 86400;      % seismogram tick spacing in seconds
        tmax = time_offset + max(time);
        tmin = time_offset + min(time);
        movieLength = max(time) - min(time);
        if(movieLength < 2.2*xTick)
           xTick = 86400;
        end;
        if(movieLength < 2.2*xTick)
           xTick = 44800;
        end;
        if(movieLength < 2.2*xTick)
           xTick = 22400;
        end;
        if(movieLength < 2.2*xTick)
           xTick = 11200;
        end;
        if(movieLength < 2.2*xTick)
           xTick = 9600;
        end;
        if(movieLength < 2.2*xTick)
           xTick = 4800;
        end;
        if(movieLength < 2.2*xTick)
           xTick = 2400;
        end;
        if(movieLength < 2.2*xTick)
           xTick = 1200;
        end;
        if(movieLength < 2.2*xTick)
           xTick = 600; 
        end;
        if(movieLength < 2.2*xTick)
           xTick = 300; 
        end;
        if(movieLength < 2.2*xTick)
           xTick = 180; 
        end;
        if(movieLength < 2.2*xTick)
           xTick = 120; 
        end;
        if(movieLength < 2.2*xTick)
           xTick = 60;
        end;

%
% to have regular tick labels at every xTick seconds
%
        %tmin = ceil(1.0*movieT(1)/xTick)*xTick;
        %tmax = floor(1.0*movieT(length(movieT))/xTick)*xTick;
        mCount = 1 + (tmax - tmin)/xTick;

        if (debug)
           fprintf('[INFO] tmin tmax mCount %d , %d, %d\n',tmin,tmax,mCount);
        end;

        %ticks = zeros(mCount);
        ticks = zeros(round(mCount));
        tickValue = tmin;
        for i=1:mCount
           ticks(i) = tickValue;
           tickValue = tickValue + xTick;
           tickCount = i;
        end;

        xTicks = get(gca,'XTick'); % get the x values for each tick mark
        xTicks = ticks;

        if (debug)
           fprintf('[INFO] time axis tick values: %d\n',xTicks);
        end;

           if length(xTicks)>7
              xTickLabels = {};
              doSkip = 0; % we want to plot every other label
              for i=1:length(xTicks)
                 if (doSkip <=0)
                    %hLabel = idivide(xTicks(i),int32(3600));
                    %mLabel = idivide(mod(xTicks(i),3600),int32(60));
                    %sLabel = xTicks(i)-hLabel*3600-mLabel*60;
                    %xTickLabels{i}  = sprintf('%02d:%02d:%02d',hLabel,mLabel,sLabel);
                    hLabel = idivide(abs(xTicks(i)),int32(3600));
                    mLabel = idivide(mod(abs(xTicks(i)),3600),int32(60));
                    sLabel = abs(xTicks(i))-hLabel*3600-mLabel*60;
                    if xTicks(i)<0
                       xTickLabels{i}  = sprintf('-%02d:%02d:%02d',hLabel,mLabel,sLabel);
                    else
                       xTickLabels{i}  = sprintf('%02d:%02d:%02d',hLabel,mLabel,sLabel);
                    end
                    if (debug)
                       fprintf('[INFO] time axis tick labels: %s\n',xTickLabels{i});
                    end;
                    doSkip = 1;
                 else
                    xTickLabels{i} = ' ';
                    doSkip = 0;
                 end;
              end; % end for loop over xTicks
           else
              for i=1:length(xTicks)
                 %hLabel = idivide(xTicks(i),int32(3600));
                 %mLabel = idivide(mod(xTicks(i),3600),int32(60));
                 %sLabel = xTicks(i)-hLabel*3600-mLabel*60;
                 %xTickLabels{i}  = sprintf('%02d:%02d:%02d',hLabel,mLabel,sLabel);
                 hLabel = idivide(abs(xTicks(i)),int32(3600));
                 mLabel = idivide(mod(abs(xTicks(i)),3600),int32(60));
                 sLabel = abs(xTicks(i))-hLabel*3600-mLabel*60;
                 if xTicks(i)<0
                    xTickLabels{i}  = sprintf('-%02d:%02d:%02d',hLabel,mLabel,sLabel);
                 else
                    xTickLabels{i}  = sprintf('%02d:%02d:%02d',hLabel,mLabel,sLabel);
                 end
              end
           end % end if statement about length of xTicks

%
% Set the time axis (no limit change, just the labels)
%
        set(gca,'XTick', [ticks(1):xTick:ticks(tickCount)]); % tick locations
        set(gca,'XTickLabel', xTickLabels); % label each tick with a string
%  >>>> ABOVE STOLEN FROM GMV <<<<<
%
%  Add IRIS logo
%
         has = axes('Position',irisLogoPosition);
         I=imread(irisLogo);
         image(I);
         daspect([1 1 1]);
         axis off;
%
%  Add SIO logo
%
         has = axes('Position',sioLogoPosition);
         I=imread(sioLogo);
         image(I);
         daspect([1 1 1]);
         axis off;
%
%  Make background color of the figure white
%
         set(gcf,'Color',[1 1 1]);
%
%  Save image
%
         set(gca, 'ActivePositionProperty', 'OuterPosition'); 
         set(gcf,'PaperUnits','inches','PaperPosition',[0.0    0.0    8.000    9.000]); % yes! This one works! But IRIS says it is too big
         %set(gcf,'PaperUnits','inches','PaperPosition',[0.0    0.0    16.000    18.000]); % need this for debi's local machine, ffmpeg needs size to be  divisible by two 
         r = 100; % pixels per inch, this one works with set(gcf,'PaperUnits','inches','PaperPosition',[0.0    0.0    6.490    7.490])
         eval(['print -djpeg100 ',sprintf('-r%d',r),' ',fileRenderName num2str(icount,'%03d') '.jpg']);
%
%  If requested save one image to use as a thumbnail for use in IRIS data product distribution
%
         if (metadata.iflag_image) 
            igrab = floor(0.35*FramesTotal);
            if icount==igrab
               eval(['print -djpeg100 ',sprintf('-r%d',r),' ',fileDirNameImage inputdata '.jpg']);
               %disp('remove .... after making poster kid ...')
               %eval(['print -depsc ',sprintf('-r%d',r),' ',fileDirNameImage inputdata '.eps']);
            end
         end
   end % end frame loop
   if debug
      disp('~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~')
      disp(['A series of ',num2str(floor(FramesTotal)),' image frames have been created.']);
      disp(['When assempling your movie please use: ']);
      disp(['     ',num2str(floor(FramesPerSecond)),' frames per second']);
      disp(['This rate will match the audio file that has a ',...
           ' duration of ',num2str(soundLength),' seconds']);
      disp(['']);
      disp(['Audio file: ',filename,'.wav'])
      %disp(['Image files: ',directory,'/Images']);
      disp(['Image files: ',num2str(irisid),'/Images']);
   end % debug
   disp('Render Finished')	
  
   fid = fopen([fileDirName,'/framerate.dat'],'w');
   fprintf(fid,'%12.8f\n',FramesPerSecond);
   fclose(fid);
 
%
% Print out metadata for use in populating IRIS web-page
%
   moviename = ['Movies/',inputdata,'_vco',name_end];
   eventname = [basedir,'/Events/',inputdata,'_vco_',num2str(metadata.movie_height),'.dat']
   fid_events = fopen(eventname,'w');
   sepit = '|';
   space = ' ';
   fprintf(fid_events,'%2.0f-%02d-%02d %02d:%02d:%02d %c %s %c %s %c %s, %c %s %c %s %c %s %c %s %c %3.0f %c %5.0f %c %5.1f\n',...
    metadata.eq_yy, metadata.eq_mm, metadata.eq_dd, metadata.eq_hh, metadata.eq_mn, metadata.eq_sc, sepit, ...
    moviename,sepit, net, sepit , data.station, space, metadata.site, sepit, ... 
    metadata.region_name, sepit,mag, sepit, metadata.depth, sepit, metadata.distgc, sepit, distkm, sepit, metadata.azimuth);
   fclose(fid_events);
%
%  Prepare ffmpeg commands
%
   dir_orig = pwd;
   line1_combine = ['cd ',fileDirName];
   line2_combine = ['!/usr/bin/ffmpeg -g 300 -r ',num2str(FramesPerSecond),' -f image2 -i img%03d.jpg -sameq test.avi'];
   line3_combine = ['!/usr/bin/ffmpeg -y -analyzeduration 1000000000  -i ../Audio/',inputdata,'.wav -i test.avi -ar 22050 -vcodec libx264 -vpre libx264-lossless_max  -vf copy ','../Movies/',inputdata,'.mp4'];
   line4_combine = ['!/usr/bin/ffmpeg -y -i ','../Movies/',inputdata,'.mp4',scaleinfo,'../Movies/',inputdata,name_end];
   line4_vco_combine = ['!/usr/bin/ffmpeg -y -i ','../Movies/',inputdata,'_vco.mp4',scaleinfo,'../Movies/',inputdata,'_vco',name_end];
   line_vco_combine = ['!/usr/bin/ffmpeg -y -analyzeduration 1000000000 -i ../Audio/',inputdata,'_vco.wav -i test.avi -ar 22050 -vcodec libx264 -vpre libx264-lossless_max  -vf copy ','../Movies/',inputdata,'_vco.mp4'];
   line5_combine = ['cd ',dir_orig];

%
%  Create requested files, while at the same time tidy up to leave only the requested files
%
   evalc(line1_combine)
%
%  Create movie if requested 
%
   if (metadata.iflag_movie) 
      evalc(line2_combine)
      eval(line3_combine)
      if (metadata.iflag_vco)
         eval(line_vco_combine)
         eval(line4_vco_combine)
      else
         eval(line4_combine)
      end
      if debug 
         disp('debug: just created movie with ffmpeg!') 
      end
   end
%
%  Remove large scale move if not wanted
%
   if ~(metadata.iflag_largescale)
      eval(['!rm ../Movies/',inputdata,'.mp4'])
      eval(['!rm ../Movies/',inputdata,'_vco.mp4'])
   end
%
%  Return to original directory and only keep sound 'wav' sound file if requested
%
   eval(line5_combine)
   if ~(metadata.iflag_sound) 
      eval(['!rm  ',audiofile]);
   end
%
%  Unless the debug flag is set remove the fileDirNameImage directory of static images that were made
%  into the movie
%
   if ~debug
     system(['rm -r ',fileDirName]);
   else
      disp(['Debug flag is set so not removing ',fileDirNameImage,' directory.'])
   end
